@@ -5,7 +5,7 @@ package Parse::AFP::Record;
 use base 'Parse::AFP::Base';
 
 use constant FORMAT => (
-    CC		=> 'C',
+    CC		=> 'H2',
     Length	=> 'n',	    # length() + 2
     Type	=> 'H6',
     FlagByte	=> 'a',
@@ -15,7 +15,7 @@ use constant FORMAT => (
 use constant DISPATCH_FIELD => 'Type';
 use constant DISPATCH_TABLE => (
     d3ab8a	=> 'MCF',
-#    d3b18a	=> 'MCF1',
+    d3b18a	=> 'MCF1',
     d3ee9b	=> 'PTX',
 );
 
